@@ -17,6 +17,7 @@
 #undef HAVE_LINUX_TABLE
 #undef HAVE_GNOME_PRINT
 #undef HAVE_LINUX_FD_H
+#undef PATH_MESSAGES
 
 /* Define if LibGTop has support for multiple processors. */
 #undef HAVE_LIBGTOP_SMP
@@ -70,3 +71,5 @@
 
 #undef USE_PAM
 #undef BUILD_GSTRIPCHART_APPLET
+
+#undef GNOME_ICONDIR
