@@ -1,4 +1,5 @@
-/* $Id: dict.c,v 1.7 2000/04/06 00:46:16 hovinen Exp $ */
+/* $Id: dict.c,v 1.9 2000/05/18 00:30:59 hovinen Exp $ */
+/* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
  *  Bradford Hovinen <hovinen@udel.edu>
@@ -24,18 +25,20 @@
 #include <errno.h>
 
 #include <unistd.h>
-#include <netdb.h>
 
 #include <glib.h>
 
 #include "dict.h"
 
+static gint dict_context_do_dns_lookup (dict_context_t *context);
+
 /* dict_res_new (name, desc)
  *
  * Constructs a new result structure
  */
 
-dict_res_t *dict_res_new (gchar *name, gchar *desc) {
+dict_res_t *dict_res_new (gchar *name, gchar *desc) 
+{
     dict_res_t *res;
     
     res = g_new0 (dict_res_t, 1);
@@ -50,7 +53,8 @@ dict_res_t *dict_res_new (gchar *name, gchar *desc) {
  * Destroys a result structure
  */
 
-void dict_res_destroy (dict_res_t *res) {
+void dict_res_destroy (dict_res_t *res) 
+{
     g_return_if_fail (res != NULL);
     
     if (res->free_name) g_free (res->name);
@@ -67,15 +71,16 @@ void dict_res_destroy (dict_res_t *res) {
  * Returns 0 on success, -1 on socket error
  */
 
-static int dict_write (dict_context_t *context, GString *str) {
+static int dict_write (dict_context_t *context, GString *str) 
+{
     int res, amt;
     
     res = g_io_channel_write(context->channel, str->str, str->len, &amt);
     
     if (res != G_IO_ERROR_NONE)
-      return -1;
+	return -1;
     else
-      return 0;
+	return 0;
 }
 
 /* dict_command_done ()
@@ -84,7 +89,8 @@ static int dict_write (dict_context_t *context, GString *str) {
  */
 
 static void
-dict_command_done (dict_command_t *command) {
+dict_command_done (dict_command_t *command) 
+{
     command->state = S_DONE;
     
     if (command->context) {
@@ -112,25 +118,26 @@ dict_command_done (dict_command_t *command) {
  */
 
 static int 
-cycle_buffer (dict_context_t *context) {
+cycle_buffer (dict_context_t *context) 
+{
     int amt_read, res;
     
     if (!context->read_cycle_done) {
         if (context->write_ptr > context->read_ptr)
-          memmove (context->read_buf, context->read_ptr,
-                   context->write_ptr - context->read_ptr);
+	    memmove (context->read_buf, context->read_ptr,
+		     context->write_ptr - context->read_ptr);
         context->write_ptr -= context->read_ptr - context->read_buf;
         context->read_ptr = context->read_buf;
         
         res = g_io_channel_read (context->channel, context->write_ptr,
                                  context->read_buf + READ_BUF_LEN 
-                                     - context->write_ptr, 
+				 - context->write_ptr, 
                                  &amt_read);
         
         if (res == G_IO_ERROR_AGAIN)
-          context->read_cycle_done = TRUE;
+	    context->read_cycle_done = TRUE;
         else if (res != G_IO_ERROR_NONE)
-          return -1;
+	    return -1;
         
         context->write_ptr += amt_read;
         return 0;
@@ -177,7 +184,8 @@ static char *dict_read_line (dict_context_t *context) {
  * Notification function called when receiving response from a MATCH command
  */
 
-static void data_notify_match (dict_context_t *context, char *line) {
+static void data_notify_match (dict_context_t *context, char *line) 
+{
     DictStatusCode status_code;
     int num_matches;
     char *word, *desc;
@@ -187,12 +195,12 @@ static void data_notify_match (dict_context_t *context, char *line) {
     command = context->command;
     
     switch (command->state) {
-      case S_GROUND:      /* Uh oh... problem */
-      case S_DONE:
+    case S_GROUND:      /* Uh oh... problem */
+    case S_DONE:
         g_error ("In ground state when invoking MATCH command");
         break;
         
-      case S_STATUS:
+    case S_STATUS:
         status_code = (DictStatusCode) atoi (line);
         while (isdigit (*line)) line++;
         while (isspace (*line)) line++;
@@ -200,41 +208,41 @@ static void data_notify_match (dict_context_t *context, char *line) {
         num_matches = 0;
         
         switch (status_code) {
-          case DICT_STATUS_MATCHES_FOUND:
+	case DICT_STATUS_MATCHES_FOUND:
             num_matches = atoi (line);
             command->state = S_DATA;
             if (command->status_notify_cb)
-              command->status_notify_cb (command, status_code, num_matches,
-                                         command->user_data);
+		command->status_notify_cb (command, status_code, num_matches,
+					   command->user_data);
             break;
             
-          case DICT_STATUS_BAD_DB:
-          case DICT_STATUS_BAD_STRAT:
-          case DICT_STATUS_BAD_COMMAND:
-          case DICT_STATUS_BAD_PARAMS:
-          case DICT_STATUS_CMD_NO_IMPL:
-          case DICT_STATUS_PARAM_NO_IMPL:
-          case DICT_STATUS_NO_ACCESS:
+	case DICT_STATUS_BAD_DB:
+	case DICT_STATUS_BAD_STRAT:
+	case DICT_STATUS_BAD_COMMAND:
+	case DICT_STATUS_BAD_PARAMS:
+	case DICT_STATUS_CMD_NO_IMPL:
+	case DICT_STATUS_PARAM_NO_IMPL:
+	case DICT_STATUS_NO_ACCESS:
             dict_command_done (command);
             if (command->error_notify_cb)
-              command->error_notify_cb (command, status_code, line,
-                                        command->user_data);
+		command->error_notify_cb (command, status_code, line,
+					  command->user_data);
             break;
             
-          case DICT_STATUS_NO_MATCH:
-          case DICT_STATUS_OK:
+	case DICT_STATUS_NO_MATCH:
+	case DICT_STATUS_OK:
             dict_command_done (command);
             if (command->status_notify_cb)
-              command->status_notify_cb (command, status_code, 0,
-                                         command->user_data);
+		command->status_notify_cb (command, status_code, 0,
+					   command->user_data);
             break;
             
-          default:
+	default:
             g_error ("Invalid status code given");
         }
         break;
         
-      case S_DATA:
+    case S_DATA:
         if (!strcmp (line, ".\n")) {
             command->state = S_STATUS;
         }
@@ -253,13 +261,13 @@ static void data_notify_match (dict_context_t *context, char *line) {
             new_res->free_desc = TRUE;
             
             command->res_tail = 
-              g_list_append (command->res_tail, new_res);
+		g_list_append (command->res_tail, new_res);
             if (!command->res_list) 
-              command->res_list = command->res_tail;
+		command->res_list = command->res_tail;
             
             if (command->data_notify_cb)
-              command->data_notify_cb (command, new_res,
-                                       command->user_data);
+		command->data_notify_cb (command, new_res,
+					 command->user_data);
         }
     }
 }
@@ -269,7 +277,8 @@ static void data_notify_match (dict_context_t *context, char *line) {
  * Notification function called when receiving response from a DEFINE command
  */
 
-static void data_notify_define (dict_context_t *context, char *line) {
+static void data_notify_define (dict_context_t *context, char *line) 
+{
     DictStatusCode status_code;
     int num_found;
     char *buf;
@@ -279,12 +288,12 @@ static void data_notify_define (dict_context_t *context, char *line) {
     command = context->command;
     
     switch (command->state) {
-      case S_GROUND:      /* Uh oh... problem */
-      case S_DONE:
+    case S_GROUND:      /* Uh oh... problem */
+    case S_DONE:
         g_error ("In ground state when invoking DEFINE command");
         break;
         
-      case S_STATUS:
+    case S_STATUS:
         status_code = (DictStatusCode) atoi (line);
         while (isdigit (*line)) line++;
         while (isspace (*line)) line++;
@@ -292,14 +301,14 @@ static void data_notify_define (dict_context_t *context, char *line) {
         num_found = 0;
         
         switch (status_code) {
-          case DICT_STATUS_DEF_RETRIEVED:
+	case DICT_STATUS_DEF_RETRIEVED:
             num_found = atoi (line);
             if (command->status_notify_cb)
-              command->status_notify_cb (command, status_code, num_found,
-                                         command->user_data);
+		command->status_notify_cb (command, status_code, num_found,
+					   command->user_data);
             break;
             
-          case DICT_STATUS_WORD_DB_NAME:
+	case DICT_STATUS_WORD_DB_NAME:
             while (*line != '\"') line++; line++;
             while (*line != '\"') line++; line++;
             while (isspace (*line)) line++;
@@ -313,32 +322,32 @@ static void data_notify_define (dict_context_t *context, char *line) {
             command->state = S_DATA;
             break;
             
-          case DICT_STATUS_BAD_DB:
-          case DICT_STATUS_BAD_COMMAND:
-          case DICT_STATUS_BAD_PARAMS:
-          case DICT_STATUS_CMD_NO_IMPL:
-          case DICT_STATUS_PARAM_NO_IMPL:
-          case DICT_STATUS_NO_ACCESS:
+	case DICT_STATUS_BAD_DB:
+	case DICT_STATUS_BAD_COMMAND:
+	case DICT_STATUS_BAD_PARAMS:
+	case DICT_STATUS_CMD_NO_IMPL:
+	case DICT_STATUS_PARAM_NO_IMPL:
+	case DICT_STATUS_NO_ACCESS:
             dict_command_done (command);
             if (command->error_notify_cb)
-              command->error_notify_cb (command, status_code, line,
-                                        command->user_data);
+		command->error_notify_cb (command, status_code, line,
+					  command->user_data);
             break;
             
-          case DICT_STATUS_NO_MATCH:
-          case DICT_STATUS_OK:
+	case DICT_STATUS_NO_MATCH:
+	case DICT_STATUS_OK:
             dict_command_done (command);
             if (command->status_notify_cb)
-              command->status_notify_cb (command, status_code, 0,
-                                         command->user_data);
+		command->status_notify_cb (command, status_code, 0,
+					   command->user_data);
             break;
             
-          default:
+	default:
             g_error ("Invalid status code given");
         }
         break;
         
-      case S_DATA:
+    case S_DATA:
         if (!strcmp (line, ".\n")) {
             new_res = dict_res_new (command->db_name, command->def->str);
             new_res->free_name = new_res->free_desc = TRUE;
@@ -350,8 +359,8 @@ static void data_notify_define (dict_context_t *context, char *line) {
             
             command->state = S_STATUS;
             if (command->data_notify_cb)
-              command->data_notify_cb (command, new_res,
-                                       command->user_data);
+		command->data_notify_cb (command, new_res,
+					 command->user_data);
         }
         else {
             g_string_append (command->def, line);
@@ -364,7 +373,8 @@ static void data_notify_define (dict_context_t *context, char *line) {
  * Notification function called when receiving response from a SHOW DB command
  */
 
-static void data_notify_show_db (dict_context_t *context, char *line) {
+static void data_notify_show_db (dict_context_t *context, char *line) 
+{
     DictStatusCode status_code;
     int num_found;
     char *name, *desc;
@@ -374,12 +384,12 @@ static void data_notify_show_db (dict_context_t *context, char *line) {
     command = context->command;
     
     switch (command->state) {
-      case S_GROUND:      /* Uh oh... problem */
-      case S_DONE:
+    case S_GROUND:      /* Uh oh... problem */
+    case S_DONE:
         g_error ("In ground state when invoking SHOW DB command");
         break;
         
-      case S_STATUS:
+    case S_STATUS:
         status_code = (DictStatusCode) atoi (line);
         while (isdigit (*line)) line++;
         while (isspace (*line)) line++;
@@ -387,28 +397,28 @@ static void data_notify_show_db (dict_context_t *context, char *line) {
         num_found = 0;
         
         switch (status_code) {
-          case DICT_STATUS_DB_PRESENT:
+	case DICT_STATUS_DB_PRESENT:
             num_found = atoi (line);
             command->state = S_DATA;
             if (command->status_notify_cb)
-              command->status_notify_cb (command, status_code, num_found,
-                                         command->user_data);
+		command->status_notify_cb (command, status_code, num_found,
+					   command->user_data);
             break;
             
-          case DICT_STATUS_NO_DB:
-          case DICT_STATUS_OK:
+	case DICT_STATUS_NO_DB:
+	case DICT_STATUS_OK:
             dict_command_done (command);
             if (command->status_notify_cb)
-              command->status_notify_cb (command, status_code, 0,
-                                         command->user_data);
+		command->status_notify_cb (command, status_code, 0,
+					   command->user_data);
             break;
             
-          default:
+	default:
             g_error ("Invalid status code given");
         }
         break;
         
-      case S_DATA:
+    case S_DATA:
         if (!strcmp (line, ".\n")) {
             command->state = S_STATUS;
         }
@@ -426,13 +436,13 @@ static void data_notify_show_db (dict_context_t *context, char *line) {
             new_res->free_desc = TRUE;
             
             command->res_tail = 
-              g_list_append (command->res_tail, new_res);
+		g_list_append (command->res_tail, new_res);
             if (!command->res_list) 
-              command->res_list = command->res_tail;
+		command->res_list = command->res_tail;
             
             if (command->data_notify_cb)
-              command->data_notify_cb (command, new_res,
-                                       command->user_data);
+		command->data_notify_cb (command, new_res,
+					 command->user_data);
         }
     }
 }
@@ -443,7 +453,9 @@ static void data_notify_show_db (dict_context_t *context, char *line) {
  * command
  */
 
-static void data_notify_show_strat (dict_context_t *context, char *line) {
+static void data_notify_show_strat (dict_context_t *context,
+				    char *line) 
+{
     DictStatusCode status_code;
     int num_found;
     char *name, *desc;
@@ -453,12 +465,12 @@ static void data_notify_show_strat (dict_context_t *context, char *line) {
     command = context->command;
     
     switch (command->state) {
-      case S_GROUND:      /* Uh oh... problem */
-      case S_DONE:
+    case S_GROUND:      /* Uh oh... problem */
+    case S_DONE:
         g_error ("In ground state when invoking SHOW STRAT command");
         break;
         
-      case S_STATUS:
+    case S_STATUS:
         status_code = (DictStatusCode) atoi (line);
         while (isdigit (*line)) line++;
         while (isspace (*line)) line++;
@@ -466,28 +478,28 @@ static void data_notify_show_strat (dict_context_t *context, char *line) {
         num_found = 0;
         
         switch (status_code) {
-          case DICT_STATUS_STRAT_PRESENT:
+	case DICT_STATUS_STRAT_PRESENT:
             num_found = atoi (line);
             command->state = S_DATA;
             if (command->status_notify_cb)
-              command->status_notify_cb (command, status_code, num_found,
-                                         command->user_data);
+		command->status_notify_cb (command, status_code, num_found,
+					   command->user_data);
             break;
             
-          case DICT_STATUS_NO_STRAT:
-          case DICT_STATUS_OK:
+	case DICT_STATUS_NO_STRAT:
+	case DICT_STATUS_OK:
             dict_command_done (command);
             if (command->status_notify_cb)
-              command->status_notify_cb (command, status_code, 0,
-                                         command->user_data);
+		command->status_notify_cb (command, status_code, 0,
+					   command->user_data);
             break;
             
-          default:
+	default:
             g_error ("Invalid status code given");
         }
         break;
         
-      case S_DATA:
+    case S_DATA:
         if (!strcmp (line, ".\n")) {
             command->state = S_STATUS;
         }
@@ -505,13 +517,13 @@ static void data_notify_show_strat (dict_context_t *context, char *line) {
             new_res->free_desc = TRUE;
             
             command->res_tail = 
-              g_list_append (command->res_tail, new_res);
+		g_list_append (command->res_tail, new_res);
             if (!command->res_list) 
-              command->res_list = command->res_tail;
+		command->res_list = command->res_tail;
             
             if (command->data_notify_cb)
-              command->data_notify_cb (command, new_res,
-                                       command->user_data);
+		command->data_notify_cb (command, new_res,
+					 command->user_data);
         }
     }
 }
@@ -521,24 +533,25 @@ static void data_notify_show_strat (dict_context_t *context, char *line) {
  * Closes the connection to the DICT server
  */
 
-static void data_notify_connect (dict_context_t *context, char *line) {
+static void data_notify_connect (dict_context_t *context, char *line) 
+{
     dict_command_t *command;
     
     command = context->command;
     
     switch (command->state) {
-      case S_GROUND:      /* Uh oh... problem */
-      case S_DATA:
-      case S_DONE:
+    case S_GROUND:      /* Uh oh... problem */
+    case S_DATA:
+    case S_DONE:
         g_error ("Bad command state");
         break;
         
-      case S_STATUS:
+    case S_STATUS:
         if (command->trigger_cmd) {
             if (command->data_notify_cb)
-              command->data_notify_cb (command, 
-                                       (dict_res_t *) command->trigger_cmd,
-                                       command->user_data);
+		command->data_notify_cb (command, 
+					 (dict_res_t *) command->trigger_cmd,
+					 command->user_data);
         }
         else {
             dict_command_destroy (command);
@@ -554,20 +567,21 @@ static void data_notify_connect (dict_context_t *context, char *line) {
  * Closes the connection to the DICT server
  */
 
-static void data_notify_quit (dict_context_t *context, char *line) {
+static void data_notify_quit (dict_context_t *context, char *line) 
+{
     gboolean reset_command_field;
     dict_command_t *command;
     
     command = context->command;
     
     switch (command->state) {
-      case S_GROUND:      /* Uh oh... problem */
-      case S_DATA:
-      case S_DONE:
+    case S_GROUND:      /* Uh oh... problem */
+    case S_DATA:
+    case S_DONE:
         g_error ("In ground state when invoking SHOW STRAT command");
         break;
         
-      case S_STATUS:
+    case S_STATUS:
         dict_disconnect (context);
         reset_command_field = !command->temp_context;
         dict_command_destroy (command);
@@ -596,17 +610,17 @@ static gboolean dict_data_notify (GIOChannel *channel, GIOCondition cond,
         
         while ((line = dict_read_line (context))) {
             if (!context->command)
-              g_error ("Data received in ground state");
+		g_error ("Data received in ground state");
             else
-              context->command->raw_data_notify_cb (context, line);
+		context->command->raw_data_notify_cb (context, line);
         }
     }
     else if (cond == G_IO_ERR) {
         if (context->command->error_notify_cb)
-          context->command->error_notify_cb (context->command, 
-                                             DICT_SOCKET_ERROR,
-                                             "Cannot connect to server",
-                                             context->command->user_data);
+	    context->command->error_notify_cb (context->command, 
+					       DICT_SOCKET_ERROR,
+					       "Cannot connect to server",
+					       context->command->user_data);
         dict_disconnect (context);
     }
     
@@ -623,22 +637,21 @@ static gboolean dict_data_notify (GIOChannel *channel, GIOCondition cond,
  * Returns pointer on success, NULL on lookup error
  */
 
-dict_context_t *dict_context_new (gchar *server, gushort port) {
+dict_context_t *dict_context_new (gchar *server, gushort port) 
+{
     dict_context_t *context;
-    struct hostent *hp;
-    char *srv = (server != NULL) ? server : DICT_DEFAULT_SERVER;
-    int p = (port > 0) ? port : DICT_DEFAULT_PORT;
 
     context = g_new0 (dict_context_t, 1);
-    
-    if ((hp = gethostbyname(srv)) == NULL)
-      return NULL;
-
+    context->hostname =
+	(server != NULL) ? server : DICT_DEFAULT_SERVER;
+    context->hostinfo = NULL;
     context->sockaddr.sin_family = AF_INET;
-    context->sockaddr.sin_port = htons(p);
-    bcopy(hp->h_addr, &context->sockaddr.sin_addr, hp->h_length);
+    context->sockaddr.sin_port =
+	htons ((port > 0) ? port : DICT_DEFAULT_PORT);
     context->read_ptr = context->write_ptr = context->read_buf;
-    
+
+    dict_context_do_dns_lookup (context);
+
     return context;
 }
 
@@ -647,13 +660,18 @@ dict_context_t *dict_context_new (gchar *server, gushort port) {
  * Clones an existing context object
  */
 
-dict_context_t *dict_context_clone (dict_context_t *context) {
+dict_context_t *dict_context_clone (dict_context_t *context) 
+{
     dict_context_t *new_context;
 
     new_context = g_new0 (dict_context_t, 1);
     
-    bcopy (&context->sockaddr, &new_context->sockaddr, sizeof (context->sockaddr));
-    new_context->read_ptr = new_context->write_ptr = new_context->read_buf;
+    bcopy (&context->sockaddr, &new_context->sockaddr,
+	   sizeof (context->sockaddr));
+    new_context->hostname = context->hostname;
+    new_context->hostinfo = context->hostinfo;
+    new_context->read_ptr = new_context->write_ptr =
+	new_context->read_buf;
     
     return new_context;
 }
@@ -663,7 +681,10 @@ dict_context_t *dict_context_clone (dict_context_t *context) {
  * Destroys a context object
  */
 
-void dict_context_destroy (dict_context_t *context) {
+void dict_context_destroy (dict_context_t *context) 
+{
+    g_return_if_fail (context != NULL);
+
     dict_disconnect (context);
     g_free (context);
 }
@@ -675,29 +696,32 @@ void dict_context_destroy (dict_context_t *context) {
  * Returns 0 on success, -1 on connection error
  */
 
-int dict_connect (dict_context_t *context) {
+int dict_connect (dict_context_t *context) 
+{
     int sock_fd;
     int old_flags;
 
+    g_return_val_if_fail (context != NULL, 0);
+
     if (context->channel) return 0;
     
     if ((sock_fd = socket(AF_INET, SOCK_STREAM, 0)) < 0)
-      return -1;
+	return -1;
     
     if ((old_flags = fcntl (sock_fd, F_GETFL, 0)) == -1)
-      return -1;
+	return -1;
     
     if (fcntl (sock_fd, F_SETFL, old_flags | O_NONBLOCK) == -1)
-      return -1;
+	return -1;
     
     if (connect(sock_fd, &context->sockaddr, sizeof(context->sockaddr)) != 0
-          && errno != EINPROGRESS)
-      return -1;
+	&& errno != EINPROGRESS)
+	return -1;
     
     context->channel = g_io_channel_unix_new (sock_fd);
     context->source_id = 
-      g_io_add_watch (context->channel, G_IO_IN | G_IO_ERR, 
-                      dict_data_notify, context);
+	g_io_add_watch (context->channel, G_IO_IN | G_IO_ERR, 
+			dict_data_notify, context);
     
     return 0;
 }
@@ -709,7 +733,10 @@ int dict_connect (dict_context_t *context) {
  * Returns 0 on success, -1 on connection error
  */
 
-void dict_disconnect (dict_context_t *context) {
+void dict_disconnect (dict_context_t *context) 
+{
+    g_return_if_fail (context != NULL);
+
     if (!context->channel) return;
     
     g_source_remove (context->source_id);
@@ -722,7 +749,8 @@ void dict_disconnect (dict_context_t *context) {
  * Create a new oommand structure
  */
 
-dict_command_t *dict_command_new (void) {
+dict_command_t *dict_command_new (void) 
+{
     dict_command_t *command;
     
     command = g_new0 (dict_command_t, 1);
@@ -735,7 +763,8 @@ dict_command_t *dict_command_new (void) {
  * Sends the command to disconnect from the server
  */
 
-dict_command_t *dict_connect_command_new (void) {
+dict_command_t *dict_connect_command_new (void) 
+{
     dict_command_t *command;
     
     command = dict_command_new ();
@@ -753,7 +782,8 @@ dict_command_t *dict_connect_command_new (void) {
  * that the server supports
  */
 
-dict_command_t *dict_disconnect_command_new (void) {
+dict_command_t *dict_disconnect_command_new (void) 
+{
     dict_command_t *command;
     
     command = dict_command_new ();
@@ -779,7 +809,9 @@ dict_command_t *dict_disconnect_command_new (void) {
  *   word: Word to check
  */
 
-dict_command_t *dict_match_command_new (char *db, char *strategy, char *word) {
+dict_command_t *dict_match_command_new (char *db, char *strategy,
+					char *word) 
+{
     dict_command_t *command;
     
     command = dict_command_new ();
@@ -810,7 +842,8 @@ dict_command_t *dict_match_command_new (char *db, char *strategy, char *word) {
  *   word: Word to find
  */
 
-dict_command_t *dict_define_command_new (char *db, char *word) {
+dict_command_t *dict_define_command_new (char *db, char *word) 
+{
     dict_command_t *command;
 
     command = dict_command_new ();
@@ -834,7 +867,8 @@ dict_command_t *dict_define_command_new (char *db, char *word) {
  * Sends the command to the server to retrieve the names of all the databases
  */
 
-dict_command_t *dict_show_db_command_new (void) {
+dict_command_t *dict_show_db_command_new (void) 
+{
     dict_command_t *command;
 
     command = dict_command_new ();
@@ -854,7 +888,8 @@ dict_command_t *dict_show_db_command_new (void) {
  * that the server supports
  */
 
-dict_command_t *dict_show_strat_command_new (void) {
+dict_command_t *dict_show_strat_command_new (void) 
+{
     dict_command_t *command;
 
     command = dict_command_new ();
@@ -873,10 +908,12 @@ dict_command_t *dict_show_strat_command_new (void) {
  * Destroys the data associated with a command object
  */
 
-void dict_command_destroy (dict_command_t *command) {
+void dict_command_destroy (dict_command_t *command) 
+{
     dict_res_t *res;
     
-    dict_command_done (command); /* Make sure it has disconnected from server */
+    /* Make sure it has disconnected from server */
+    dict_command_done (command);
     
     g_free (command->search_term);
     g_free (command->search_db);
@@ -886,7 +923,7 @@ void dict_command_destroy (dict_command_t *command) {
         res = (dict_res_t *) command->res_list->data;
         dict_res_destroy (res);
         command->res_list = 
-          g_list_remove_link (command->res_list, command->res_list);
+	    g_list_remove_link (command->res_list, command->res_list);
     }
     
     g_free (command);
@@ -904,22 +941,29 @@ static void trigger_cmd (dict_command_t *command, dict_command_t *trigger_cmd,
  *
  * Sends the command to the server associated with the given context
  *
- * Returns 0 on success, -1 on socket error, -2 on bad context
+ * Returns 0 on success, -1 on socket error, -2 on DNS lookup failure
  */
 
-int dict_command_invoke (dict_command_t *command, dict_context_t *context) {
+int dict_command_invoke (dict_command_t *command,
+			 dict_context_t *context) 
+{
     dict_command_t *sec_cmd;
     
+    g_return_val_if_fail (command != NULL, 0);
+    g_return_val_if_fail (context != NULL || command->context != NULL, 0);
+
     if (!context) context = command->context;
-    
-    g_return_val_if_fail (context != NULL, -2);
-    
+
+    if (context->hostinfo == NULL) {
+	if (dict_context_do_dns_lookup (context) < 0) return -2;
+    }
+
     /* If the context is already in use, clone it and set the new context
      * to temporary (unless it is a connect or disconnect commmand)
      */
      
     if (context->command
-         && command->cmd != C_CONNECT && command->cmd != C_DISCONNECT)
+	&& command->cmd != C_CONNECT && command->cmd != C_DISCONNECT)
     {
         command->context = dict_context_clone (context);
         command->temp_context = TRUE;
@@ -976,3 +1020,27 @@ int dict_command_invoke (dict_command_t *command, dict_context_t *context) {
     
     return 0;
 }
+
+/* dict_context_do_dns_lookup (context)
+ * 
+ * Perform DNS lookup on a context and set the host info and server
+ * address fields based on the results
+ * 
+ * Returns 0 on success, -1 on lookup failure
+ */
+
+gint dict_context_do_dns_lookup (dict_context_t *context) 
+{
+    g_return_val_if_fail (context != NULL, 0);
+
+    if (context->hostinfo != NULL) return 0;
+
+    if ((context->hostinfo = gethostbyname (context->hostname)) != NULL) {
+	bcopy(context->hostinfo->h_addr, &context->sockaddr.sin_addr,
+	      context->hostinfo->h_length);
+	return 0;
+    }
+    else {
+	return -1;
+    }
+}
