@@ -1,4 +1,4 @@
-/* $Id: gdict-applet.c,v 1.9 2000/04/06 00:46:16 hovinen Exp $ */
+/* $Id: gdict-applet.c,v 1.11 2000/05/19 15:01:03 hovinen Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -51,16 +51,32 @@ applet_detach_cb (AppletWidget *widget, gpointer data)
     return FALSE;
 }
 
+static void
+applet_show_hide_defbox_cb (AppletWidget *widget, gpointer data) 
+{
+    if (!GTK_WIDGET_VISIBLE (gdict_app))
+        gtk_widget_show (gdict_app);
+    else
+        gtk_widget_hide (gdict_app);
+}
+
+static void
+applet_spell_cb (AppletWidget *widget, gpointer data) 
+{
+    gchar *text;
+
+    text = gtk_entry_get_text (GTK_ENTRY (applet_entry));
+    gdict_spell (text, FALSE);
+    gtk_entry_set_text (GTK_ENTRY (applet_entry), "");
+}
+
 static void
 applet_clicked_cb (GtkWidget *widget, GdkEventButton *ev, gpointer data)
 {
     if ((ev == NULL) || (ev->button != 1) || (ev->type != GDK_2BUTTON_PRESS ))
         return;
 
-    if (!GTK_WIDGET_VISIBLE(gdict_app))
-        gtk_widget_show(gdict_app);
-    else
-        gtk_widget_hide(gdict_app);
+    applet_show_hide_defbox_cb (APPLET_WIDGET (widget), data);
 }
 
 static void
@@ -70,7 +86,8 @@ applet_about_cb (AppletWidget *widget, gpointer data)
 }
 
 static void
-applet_pref_cb (AppletWidget *widget, gpointer data) {
+applet_pref_cb (AppletWidget *widget, gpointer data) 
+{
     gdict_app_show_preferences ();
 }
 
@@ -102,20 +119,31 @@ void gdict_applet_create (void)
     if ((gdict_applet = applet_widget_new(PACKAGE)) == NULL)
         g_error(_("Cannot create applet!\n"));
 
-    gtk_widget_set_events (gdict_applet, gtk_widget_get_events(gdict_applet) | \
+    gtk_widget_set_events (gdict_applet, 
+			   gtk_widget_get_events(gdict_applet) |
                            GDK_BUTTON_PRESS_MASK | GDK_EXPOSURE_MASK );
     gtk_signal_connect (GTK_OBJECT(gdict_applet), "button_press_event",
                         GTK_SIGNAL_FUNC(applet_clicked_cb), NULL);
-    applet_widget_register_stock_callback (APPLET_WIDGET(gdict_applet), "about",
-                                           GNOME_STOCK_MENU_ABOUT, _("About..."),
-                                           applet_about_cb, NULL);
-    applet_widget_register_stock_callback (APPLET_WIDGET(gdict_applet), "preferences",
-                                           GNOME_STOCK_MENU_PREF, _("Preferences..."),
-                                           applet_pref_cb, NULL);
+
+    applet_widget_register_stock_callback 
+	(APPLET_WIDGET (gdict_applet), "about",
+	 GNOME_STOCK_MENU_ABOUT, _("About..."),
+	 applet_about_cb, NULL);
+    applet_widget_register_stock_callback 
+	(APPLET_WIDGET (gdict_applet), "preferences",
+	 GNOME_STOCK_MENU_PREF, _("Preferences..."),
+	 applet_pref_cb, NULL);
+    applet_widget_register_callback
+	(APPLET_WIDGET (gdict_applet), "show_hide_window", 
+	 _("Show/Hide Definition Window..."), applet_show_hide_defbox_cb,
+	 NULL);
+    applet_widget_register_callback
+	(APPLET_WIDGET (gdict_applet), "spell_check", 
+	 _("Spell Check..."), applet_spell_cb, NULL);
+
     gtk_signal_connect (GTK_OBJECT(gdict_applet), "destroy",
                         GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
 
-
     vbox = gtk_vbox_new(FALSE, 2);
     gtk_container_set_border_width (GTK_CONTAINER(vbox), 2);
     gtk_widget_show(vbox);
