@@ -1,4 +1,4 @@
-/* $Id: gdict-defbox.c,v 1.1 2000/04/06 00:46:16 hovinen Exp $ */
+/* $Id: gdict-defbox.c,v 1.3 2000/05/19 00:18:59 hovinen Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -207,9 +207,10 @@ gdict_defbox_lookup (GDictDefbox *defbox, gchar *text) {
     defbox->def_cmd->status_notify_cb = def_status_cb;
     defbox->def_cmd->data_notify_cb = def_data_cb;
     defbox->def_cmd->user_data = defbox;
-    
-    if (dict_command_invoke (defbox->def_cmd, defbox->context) < 0) return -1;
-    
+
+    if (dict_command_invoke (defbox->def_cmd, defbox->context) < 0)
+	return -1;
+
     return 0;
 }
 
@@ -261,7 +262,9 @@ gdict_defbox_find (GDictDefbox *defbox, gchar *text, gboolean start) {
     findp = strstr(lastp, text);
 
     if (findp) {
-        gtk_editable_select_region(GTK_EDITABLE(defbox), (findp - deftext), (findp - deftext) + strlen(text));
+        gtk_editable_select_region (GTK_EDITABLE(defbox),
+				    (findp - deftext),
+				    (findp - deftext) + strlen(text));
         lastp = findp + 1;
     } 
     else {
