@@ -1,4 +1,4 @@
-/* $Id: gdict-pref-dialog.c,v 1.1 2000/04/06 00:46:16 hovinen Exp $ */
+/* $Id: gdict-pref-dialog.c,v 1.4 2000/05/18 00:28:11 hovinen Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -42,7 +42,7 @@ static gchar *typeface_sel_names[NUM_TYPEFACES] = {
     N_("Main body:"),
     N_("Sub-number:"),
     N_("Part of speech:"),
-    N_("Cross-refenrece:")
+    N_("Cross-reference:")
 };
 
 #define NUM_TYPEFACE_ROWS 4
@@ -183,9 +183,10 @@ gdict_pref_dialog_init (GDictPrefDialog *pref_dialog) {
     gtk_widget_show (GTK_WIDGET (pref_dialog->strat_list));
     
     label = gtk_label_new (_("Server"));
-    gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), 
-                                gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 0), 
-                                label);
+    gtk_notebook_set_tab_label
+	(GTK_NOTEBOOK (notebook), 
+	 gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 0), 
+	 label);
     
     gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
     
@@ -232,9 +233,10 @@ gdict_pref_dialog_init (GDictPrefDialog *pref_dialog) {
     gtk_widget_show_all (table1);
     
     label = gtk_label_new (_("Fonts"));
-    gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), 
-                                gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 1), 
-                                label);
+    gtk_notebook_set_tab_label
+	(GTK_NOTEBOOK (notebook), 
+	 gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 1), 
+	 label);
     
     if (gdict_applet_toggle) {
         vbox = gtk_vbox_new (FALSE, 2);
@@ -245,7 +247,8 @@ gdict_pref_dialog_init (GDictPrefDialog *pref_dialog) {
         gtk_box_pack_start (GTK_BOX (vbox), alignment, FALSE, FALSE, 0);
 
         pref_dialog->applet_handle_btn = 
-            GTK_CHECK_BUTTON (gtk_check_button_new_with_label (_("Display handle bar")));
+            GTK_CHECK_BUTTON (gtk_check_button_new_with_label
+			      (_("Display handle bar")));
         gtk_container_add (GTK_CONTAINER (alignment), 
                            GTK_WIDGET (pref_dialog->applet_handle_btn));
         
@@ -257,14 +260,18 @@ gdict_pref_dialog_init (GDictPrefDialog *pref_dialog) {
         gtk_widget_show_all (vbox);
         
         label = gtk_label_new (_("Applet"));
-        gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), 
-                                    gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 2), 
-                                    label);
+        gtk_notebook_set_tab_label
+	    (GTK_NOTEBOOK (notebook), 
+	     gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 2), 
+	     label);
     }
 
-    gnome_dialog_append_button (GNOME_DIALOG (pref_dialog), GNOME_STOCK_BUTTON_OK);
-    gnome_dialog_append_button (GNOME_DIALOG (pref_dialog), GNOME_STOCK_BUTTON_APPLY);
-    gnome_dialog_append_button (GNOME_DIALOG (pref_dialog), GNOME_STOCK_BUTTON_CANCEL);
+    gnome_dialog_append_button (GNOME_DIALOG (pref_dialog),
+				GNOME_STOCK_BUTTON_OK);
+    gnome_dialog_append_button (GNOME_DIALOG (pref_dialog),
+				GNOME_STOCK_BUTTON_APPLY);
+    gnome_dialog_append_button (GNOME_DIALOG (pref_dialog),
+				GNOME_STOCK_BUTTON_CANCEL);
 
     gnome_dialog_button_connect (GNOME_DIALOG (pref_dialog), 0,
                                  GTK_SIGNAL_FUNC (pref_dialog_ok_cb),
@@ -278,14 +285,18 @@ gdict_pref_dialog_init (GDictPrefDialog *pref_dialog) {
     
     gnome_dialog_set_default (GNOME_DIALOG (pref_dialog), 1);
     
-    gtk_entry_set_text (GTK_ENTRY (pref_dialog->server_entry), gdict_pref.server);
+    gtk_entry_set_text (GTK_ENTRY (pref_dialog->server_entry),
+			gdict_pref.server);
     port_str = g_strdup_printf("%d", (int) gdict_pref.port);
     gtk_entry_set_text (GTK_ENTRY (pref_dialog->port_entry), port_str);
     g_free(port_str);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pref_dialog->smart_lookup_btn), gdict_pref.smart);
+    gtk_toggle_button_set_active
+	(GTK_TOGGLE_BUTTON (pref_dialog->smart_lookup_btn), gdict_pref.smart);
 
     if (gdict_applet_toggle)
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pref_dialog->applet_handle_btn), gdict_pref.applet_handle);
+        gtk_toggle_button_set_active
+	    (GTK_TOGGLE_BUTTON(pref_dialog->applet_handle_btn),
+	     gdict_pref.applet_handle);
     
     for (i = 0; i < NUM_TYPEFACES; i++) {
         gnome_font_picker_set_font_name (pref_dialog->font_pickers[i], 
@@ -301,19 +312,22 @@ gdict_pref_dialog_init (GDictPrefDialog *pref_dialog) {
 
 /* gdict_pref_dialog_class_init
  *
- * Initialises a structure describing the GDictPrefDialog class; sets up signals
- * for pref_dialog events in the Gtk signal management system
+ * Initialises a structure describing the GDictPrefDialog class; sets
+ * up signals for pref_dialog events in the Gtk signal management
+ * system
  */
 
 static void 
-gdict_pref_dialog_class_init (GDictPrefDialogClass *class) {
+gdict_pref_dialog_class_init (GDictPrefDialogClass *class) 
+{
     GtkObjectClass *object_class;
     
     object_class = (GtkObjectClass *) class;
     
     gdict_pref_dialog_signals[APPLY_CHANGES_SIGNAL] =
         gtk_signal_new ("apply_changes", GTK_RUN_FIRST, object_class->type,
-                        GTK_SIGNAL_OFFSET (GDictPrefDialogClass, apply_changes),
+                        GTK_SIGNAL_OFFSET (GDictPrefDialogClass,
+					   apply_changes),
                         gtk_signal_default_marshaller, GTK_TYPE_NONE, 0);
     
     gdict_pref_dialog_signals[SOCKET_ERROR_SIGNAL] =
@@ -336,12 +350,18 @@ gdict_pref_dialog_class_init (GDictPrefDialogClass *class) {
  */
 
 GtkWidget *
-gdict_pref_dialog_new (dict_context_t *context) {
+gdict_pref_dialog_new (dict_context_t *context) 
+{
     GDictPrefDialog *pref_dialog;
     
-    g_return_val_if_fail (context != NULL, NULL);
+    /* g_return_val_if_fail (context != NULL, NULL); */
+    /* the above is commented out because it prints ugly debug messages
+     * to the console */
+    if (context == NULL)
+	    return NULL;
     
-    pref_dialog = GDICT_PREF_DIALOG (gtk_type_new (gdict_pref_dialog_get_type ()));
+    pref_dialog =
+	GDICT_PREF_DIALOG (gtk_type_new (gdict_pref_dialog_get_type ()));
     pref_dialog->context = context;
     pref_dialog_reset_db (pref_dialog);
     pref_dialog_reset_strat (pref_dialog);
@@ -355,7 +375,8 @@ gdict_pref_dialog_new (dict_context_t *context) {
  */
 
 void
-gdict_pref_dialog_destroy (GDictPrefDialog *pref_dialog) {
+gdict_pref_dialog_destroy (GDictPrefDialog *pref_dialog) 
+{
     dict_command_destroy (pref_dialog->get_db_cmd);
     dict_command_destroy (pref_dialog->get_strat_cmd);
 }
@@ -366,7 +387,8 @@ gdict_pref_dialog_destroy (GDictPrefDialog *pref_dialog) {
  */
 
 static void
-pref_set_db_cb (GtkWidget *widget, gpointer data) {
+pref_set_db_cb (GtkWidget *widget, gpointer data) 
+{
     GDictPrefDialog *pref_dialog;
     
     pref_dialog = GDICT_PREF_DIALOG (data);
@@ -380,7 +402,8 @@ pref_set_db_cb (GtkWidget *widget, gpointer data) {
  */
 
 static void
-pref_set_strat_cb (GtkWidget *widget, gpointer data) {
+pref_set_strat_cb (GtkWidget *widget, gpointer data) 
+{
     GDictPrefDialog *pref_dialog;
     
     pref_dialog = GDICT_PREF_DIALOG (data);
@@ -394,7 +417,9 @@ pref_set_strat_cb (GtkWidget *widget, gpointer data) {
  */
 
 static void
-pref_dialog_add_db (GDictPrefDialog *pref_dialog, gchar *db, gchar *desc) {
+pref_dialog_add_db (GDictPrefDialog *pref_dialog, gchar *db,
+		    gchar *desc) 
+{
     GtkWidget *menu_item;
     
     menu_item = gtk_menu_item_new_with_label (desc);
@@ -415,7 +440,9 @@ pref_dialog_add_db (GDictPrefDialog *pref_dialog, gchar *db, gchar *desc) {
  */
 
 static void
-pref_dialog_add_strat (GDictPrefDialog *pref_dialog, gchar *strat, gchar *desc) {
+pref_dialog_add_strat (GDictPrefDialog *pref_dialog, gchar *strat,
+		       gchar *desc) 
+{
     GtkWidget *menu_item;
     
     menu_item = gtk_menu_item_new_with_label (desc);
@@ -426,7 +453,8 @@ pref_dialog_add_strat (GDictPrefDialog *pref_dialog, gchar *strat, gchar *desc)
     gtk_menu_append (pref_dialog->strat_list, menu_item);
     
     if (!strcmp (pref_dialog->dfl_strat, strat))
-      gtk_menu_set_active (pref_dialog->strat_list, pref_dialog->dfl_strat_idx);
+	gtk_menu_set_active (pref_dialog->strat_list,
+			     pref_dialog->dfl_strat_idx);
     pref_dialog->dfl_strat_idx++;
 }
 
@@ -438,6 +466,8 @@ pref_dialog_add_strat (GDictPrefDialog *pref_dialog, gchar *strat, gchar *desc)
 
 static void
 pref_dialog_reset_db (GDictPrefDialog *pref_dialog) {
+    GtkWidget *error_label, *alignment;
+
     if (pref_dialog->get_db_cmd)
       dict_command_destroy (pref_dialog->get_db_cmd);
     
@@ -459,9 +489,19 @@ pref_dialog_reset_db (GDictPrefDialog *pref_dialog) {
     
     pref_dialog_add_db (pref_dialog, "!", "Search all databases");
     
-    /* FIXME: Show error status */
-    if (dict_command_invoke (pref_dialog->get_db_cmd, pref_dialog->context) == -1)
-      return;
+    if (dict_command_invoke (pref_dialog->get_db_cmd,
+			     pref_dialog->context) == -1)
+    {
+	/* Could not look up search strategies, so just display a
+	 * label; FIXME: Memory leak
+	 */
+	error_label = gtk_label_new (_("Cannot connect to server"));
+        alignment = gtk_alignment_new (0, 0.5, 0, 0);
+        gtk_container_add (GTK_CONTAINER (alignment), 
+                           GTK_WIDGET (error_label));
+        gtk_table_attach_defaults (pref_dialog->table, alignment, 1, 2, 3, 4);
+        gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
+    }
 }
 
 /* pref_dialog_reset_strat
@@ -472,8 +512,10 @@ pref_dialog_reset_db (GDictPrefDialog *pref_dialog) {
 
 static void
 pref_dialog_reset_strat (GDictPrefDialog *pref_dialog) {
+    GtkWidget *error_label, *alignment;
+
     if (pref_dialog->get_strat_cmd)
-      dict_command_destroy (pref_dialog->get_strat_cmd);
+	dict_command_destroy (pref_dialog->get_strat_cmd);
     
     if (pref_dialog->strat_sel) {
         gtk_option_menu_remove_menu (pref_dialog->strat_sel);
@@ -491,9 +533,19 @@ pref_dialog_reset_strat (GDictPrefDialog *pref_dialog) {
     pref_dialog->get_strat_cmd->user_data = pref_dialog;
     pref_dialog->dfl_strat_idx = 0;
     
-    /* FIXME: Show error status */
-    if (dict_command_invoke (pref_dialog->get_strat_cmd, pref_dialog->context) == -1)
-      return;
+    if (dict_command_invoke (pref_dialog->get_strat_cmd,
+			     pref_dialog->context) == -1) 
+    {
+	/* Could not look up search strategies, so just display a
+	 * label; FIXME: Memory leak
+	 */
+	error_label = gtk_label_new (_("Cannot connect to server"));
+        alignment = gtk_alignment_new (0, 0.5, 0, 0);
+        gtk_container_add (GTK_CONTAINER (alignment), 
+                           GTK_WIDGET (error_label));
+        gtk_table_attach_defaults (pref_dialog->table, alignment, 1, 2, 4, 5);
+        gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
+    }
 }
 
 /* pref_dialog_update_pref
@@ -512,7 +564,8 @@ pref_dialog_update_pref (GDictPrefDialog *pref_dialog, gboolean save_prefs) {
     
     server = gtk_entry_get_text (pref_dialog->server_entry);
     port = gtk_entry_get_text (pref_dialog->port_entry);
-    smart = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (pref_dialog->smart_lookup_btn));
+    smart = gtk_toggle_button_get_active
+	(GTK_TOGGLE_BUTTON (pref_dialog->smart_lookup_btn));
     
     if (strcmp (gdict_pref.server, server) || gdict_pref.port != atoi (port)) {
         old_server = gdict_pref.server; old_port = gdict_pref.port;
@@ -521,10 +574,10 @@ pref_dialog_update_pref (GDictPrefDialog *pref_dialog, gboolean save_prefs) {
         
         /* Try connecting. If we fail, restore the old config and abort */
         if (gdict_init_context ()) {
-            gdict_pref.server = old_server;
-            gdict_pref.port = old_port;
-            return -1;
-        }
+	    gnome_error_dialog_parented (_("The server you specified could not be found."), 
+					 GTK_WINDOW (gdict_app));
+	    return -1;
+	}
         
         pref_dialog->context = context;
         
@@ -554,11 +607,12 @@ pref_dialog_update_pref (GDictPrefDialog *pref_dialog, gboolean save_prefs) {
     
     if (gdict_applet_toggle) {
         gdict_pref.applet_handle = 
-            gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (pref_dialog->applet_handle_btn));
+            gtk_toggle_button_get_active
+	              (GTK_TOGGLE_BUTTON (pref_dialog->applet_handle_btn));
     }
     
     if (save_prefs)
-      gdict_pref_save();
+	gdict_pref_save();
     
     return 0;
 }
@@ -604,9 +658,9 @@ pref_data_cb (dict_command_t *command, dict_res_t *res, gpointer data) {
     
     pref_dialog = GDICT_PREF_DIALOG (data);
     if (command->cmd == C_SHOW_DB)
-      pref_dialog_add_db (pref_dialog, res->name, res->desc);
+	pref_dialog_add_db (pref_dialog, res->name, res->desc);
     else if (command->cmd == C_SHOW_STRAT)
-      pref_dialog_add_strat (pref_dialog, res->name, res->desc);
+	pref_dialog_add_strat (pref_dialog, res->name, res->desc);
 }
 
 /* pref_status_cb
@@ -642,15 +696,16 @@ pref_status_cb (dict_command_t *command, DictStatusCode code,
         option_menu = GTK_OPTION_MENU (gtk_option_menu_new ());
         gtk_option_menu_set_menu (option_menu, GTK_WIDGET (use_menu));
         alignment = gtk_alignment_new (0, 0.5, 0, 0);
-        gtk_container_add (GTK_CONTAINER (alignment), GTK_WIDGET (option_menu));
+        gtk_container_add (GTK_CONTAINER (alignment),
+			   GTK_WIDGET (option_menu));
         gtk_table_attach_defaults (pref_dialog->table, alignment, 
                                    1, 2, row, row + 1);
         gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
         
         if (command->cmd == C_SHOW_DB)
-          pref_dialog->db_sel = option_menu;
+	    pref_dialog->db_sel = option_menu;
         else if (command->cmd == C_SHOW_STRAT)
-          pref_dialog->strat_sel = option_menu;
+	    pref_dialog->strat_sel = option_menu;
     }
 }
 
