@@ -1,4 +1,4 @@
-/* $Id: gdict-speller.c,v 1.1 2000/04/06 00:46:16 hovinen Exp $ */
+/* $Id: gdict-speller.c,v 1.2 2000/05/18 00:29:48 hovinen Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -356,8 +356,10 @@ gdict_speller_get_word (GDictSpeller *speller) {
 
 void
 gdict_speller_reset_strat (GDictSpeller *speller) {
+    GtkWidget *error_label, *alignment;
+
     if (speller->get_strat_cmd)
-      dict_command_destroy (speller->get_strat_cmd);
+	dict_command_destroy (speller->get_strat_cmd);
     
     if (speller->strat_sel) {
         gtk_option_menu_remove_menu (speller->strat_sel);
@@ -375,8 +377,19 @@ gdict_speller_reset_strat (GDictSpeller *speller) {
     speller->get_strat_cmd->user_data = speller;
     speller->strat_idx = 0;
     
-    if (dict_command_invoke (speller->get_strat_cmd, speller->context) == -1)
-      return;
+    if (dict_command_invoke (speller->get_strat_cmd,
+			     speller->context) == -1) 
+    {
+	/* Could not look up search strategies, so just display a
+	 * label; FIXME: Memory leak
+	 */
+	error_label = gtk_label_new (_("Cannot connect to server"));
+        alignment = gtk_alignment_new (0, 0.5, 0, 0);
+        gtk_container_add (GTK_CONTAINER (alignment), 
+                           GTK_WIDGET (error_label));
+        gtk_table_attach_defaults (speller->table, alignment, 1, 2, 1, 2);
+        gtk_widget_show_all (GTK_WIDGET (speller->table));
+    }
 }
 
 /* spell_error_cb
