@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.12 2000/04/16 23:05:49 hovinen Exp $ */
+/* $Id: main.c,v 1.15 2000/05/18 00:33:34 hovinen Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -20,6 +20,8 @@
 #include <assert.h>
 
 #include <gnome.h>
+#include <applet-widget.h>
+#include <libgnomeui/gnome-window-icon.h>
 
 #include "dict.h"
 #include "gdict-pref.h"
@@ -75,15 +77,20 @@ int main (int argc, char *argv[])
 
         if ((client = gnome_master_client()) != NULL)
             gtk_signal_connect (GTK_OBJECT(client), "save_yourself",
-                                GTK_SIGNAL_FUNC(save_yourself_cb), (gpointer)argv[0]);
+                                GTK_SIGNAL_FUNC(save_yourself_cb),
+				(gpointer) argv[0]);
     } else {
         applet_widget_init(PACKAGE, VERSION, argc, argv,
                            args, 0, NULL );
     }
 
+    gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gdict.png");
     gdict_app_create ();
     gdict_pref_load ();
-    gdict_init_context ();
+    if ((gdict_init_context () < 0) && (gdict_applet_toggle == FALSE))
+	    return 0;
+    /* If we can not find the context then we may as well just quit
+     * since nothing is usable anymore. But not if we're an applet */
     defbox->context = context;
 
     if (gdict_applet_toggle)
