@@ -1,5 +1,5 @@
 /* -*- Mode: C -*-
- * $Id: gdiskfree.c,v 1.6 2000/04/10 10:18:00 frob Exp $
+ * $Id: gdiskfree.c,v 1.7 2000/05/05 05:36:22 jberkman Exp $
  *
  * GDiskFree -- A disk free space toy (df on steriods).
  * Copyright 1998,1999 Gregory McLean
@@ -24,6 +24,7 @@
 #endif
 
 #include <gnome.h>
+#include <libgnomeui/gnome-window-icon.h>
 #include "gdiskfree_app.h"
 #include "gdiskfree_options.h"
 
@@ -95,6 +96,7 @@ main (int argc, gchar *argv[])
   textdomain (PACKAGE);
   
   gnome_init_with_popt_table (PACKAGE, VERSION, argc, argv, options, 0, &pctx);
+  gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-diskfree.png");
   poptFreeContext (pctx);
   /** Get the configuration (or default) **/
   gdiskfree_option_init ();
