@@ -1,10 +1,8 @@
 #include "mdi-color-generic.h"
 #include "view-color-generic.h"
-#include "view-color-list.h"
-#include "view-color-grid.h"
-#include "view-color-edit.h"
 #include "menus.h"
 #include "utils.h"
+#include "gcolorsel.h"
 
 #include <gnome.h>
 #include <glade/glade.h>
@@ -17,11 +15,13 @@ static void mdi_color_generic_document_changed (MDIColorGeneric *mcg,
 static GtkWidget *
 mdi_color_generic_create_view                  (MDIColorGeneric *child);
 
-static GList *mdi_color_generic_get_append_pos   (MDIColorGeneric *mcg, 
-						MDIColor *col);
 static void mdi_color_generic_free_col         (MDIColor *col);
 static GList *mdi_color_generic_find_col       (MDIColorGeneric *mcg, int pos);
 
+static void mdi_color_generic_clear_all_other_views (MDIColorGeneric *mcg);
+static void mdi_color_generic_set_all_color_change (MDIColorGeneric *mcg, 
+						    int val);
+
 static gpointer
 mdi_color_generic_get_control       (MDIColorGeneric *vcg, GtkVBox *box,
 				     void (*changed_cb)(gpointer data), 
@@ -76,7 +76,6 @@ mdi_color_generic_class_init (MDIColorGenericClass *class)
   object_class          = GTK_OBJECT_CLASS (class);
   mdi_child_class       = GNOME_MDI_CHILD_CLASS (class);
   parent_class          = gtk_type_class (gnome_mdi_child_get_type());
-  object_class->destroy = mdi_color_generic_destroy;
 
   mcg_signals [DOCUMENT_CHANGED] = 
     gtk_signal_new ("document_changed",
@@ -88,7 +87,6 @@ mdi_color_generic_class_init (MDIColorGenericClass *class)
 
   gtk_object_class_add_signals (object_class, mcg_signals, LAST_SIGNAL);
 
-
   mdi_child_class->create_view = (GnomeMDIChildViewCreator)mdi_color_generic_create_view;
 
   class->document_changed = mdi_color_generic_document_changed;
@@ -99,13 +97,19 @@ mdi_color_generic_class_init (MDIColorGenericClass *class)
   class->load             = mdi_color_generic_load;
   class->save             = mdi_color_generic_save;
 
+  object_class->destroy   = mdi_color_generic_destroy;
+
   mdi_child_class->get_config_string = (GnomeMDIChildConfigFunc)get_config_string;
 }
 
 static void
 mdi_color_generic_init (MDIColorGeneric *mcg)
 {
-  mcg->key          = get_config_key ();
+  mcg->key  = get_config_key ();
+  mcg->name = NULL;
+
+  mcg->modified         = FALSE;
+  mcg->monitor_modified = FALSE;
 
   mcg->freeze_count = 0;
   mcg->last         = -1;
@@ -119,6 +123,8 @@ mdi_color_generic_init (MDIColorGeneric *mcg)
   mcg->get_control_type = NULL;
   mcg->changes_phase    = 1;
 
+  mcg->temp = FALSE;
+
   mcg->flags = CHANGE_APPEND | CHANGE_REMOVE | CHANGE_NAME | CHANGE_POS
                      | CHANGE_RGB | CHANGE_CLEAR;
   
@@ -128,7 +134,25 @@ mdi_color_generic_init (MDIColorGeneric *mcg)
 static void 
 mdi_color_generic_destroy (GtkObject *obj)
 {
-  //MDIColor *child = MDI_COLOR_GENERIC(obj);
+  MDIColorGeneric *mcg = MDI_COLOR_GENERIC (obj);
+    
+  mdi_color_generic_set_all_color_change (mcg, CHANGE_REMOVE);
+
+  while (mcg->parents) 
+    mdi_color_generic_disconnect (mcg->parents->data, mcg);
+
+  mdi_color_generic_clear_all_other_views (mcg);    
+
+  while (mcg->other_views) 
+    mdi_color_generic_disconnect (mcg, mcg->other_views->data); 
+
+  mcg->freeze_count++;
+  mdi_color_generic_clear (mcg);
+
+  if (mcg->changes) g_list_free (mcg->changes);
+  if (mcg->other_views) g_list_free (mcg->other_views);
+  if (mcg->parents) g_list_free (mcg->parents);
+  if (mcg->views_type) g_list_free (mcg->views_type);
   
   if(GTK_OBJECT_CLASS(parent_class)->destroy)
     (* GTK_OBJECT_CLASS(parent_class)->destroy)(obj);
@@ -137,8 +161,6 @@ mdi_color_generic_destroy (GtkObject *obj)
 static const gchar * 
 get_config_string (GnomeMDIChild *child) 
 {
-  printf ("GetConfigString ...\n");
-
   return g_strdup_printf ("%d", MDI_COLOR_GENERIC (child)->key);
 }
 
@@ -177,6 +199,7 @@ mdi_color_generic_create_view (MDIColorGeneric *child)
   ControlGeneric *control = NULL;
   ViewColorGeneric *view = NULL;
   int type;
+  views_t *views;
 
   vbox = gtk_vbox_new (FALSE, 0);
 
@@ -194,30 +217,25 @@ mdi_color_generic_create_view (MDIColorGeneric *child)
     type = GPOINTER_TO_INT (child->views_type->data);
     child->views_type = g_list_remove (child->views_type, 
 				       child->views_type->data);
+
+    views = get_views_from_type (type);
   } else
-    type = view_color_list_get_type ();
+    views = &views_tab[0];
 
-  /* Create scrolled window, if needed and view*/
+  /* Create scrolled window */
 
-  if (type == TYPE_VIEW_COLOR_LIST) { /* List */
+  if ((views->scroll_h_policy != GTK_POLICY_NEVER) ||
+      (views->scroll_v_policy != GTK_POLICY_NEVER)) {
+    
     sw = gtk_scrolled_window_new (NULL, NULL);  
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
-				    GTK_POLICY_AUTOMATIC,
-				    GTK_POLICY_ALWAYS);
+				    views->scroll_h_policy,
+				    views->scroll_v_policy);
+  }
 
-    view = VIEW_COLOR_GENERIC (view_color_list_new (child)); 
-  } else 
-    if (type == TYPE_VIEW_COLOR_GRID) { /* Grid */
-      sw = gtk_scrolled_window_new (NULL, NULL);  
-      gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
-				      GTK_POLICY_NEVER,
-				      GTK_POLICY_AUTOMATIC);
-      view = VIEW_COLOR_GENERIC (view_color_grid_new (child)); 
-    } else
-      if (type == TYPE_VIEW_COLOR_EDIT) {
-	view = VIEW_COLOR_GENERIC (view_color_edit_new (child));
-      } else
-	g_assert_not_reached ();
+  /* Create view */
+
+  view = VIEW_COLOR_GENERIC (views->new (child));
 
   /* Pack view */
 
@@ -239,12 +257,15 @@ mdi_color_generic_create_view (MDIColorGeneric *child)
 
   /* Sync control */
 
-  
   if (control) 
     control_generic_sync (CONTROL_GENERIC (control));
 
   gtk_widget_show_all (vbox);
 
+  gtk_signal_connect_object (GTK_OBJECT (vbox), "destroy",
+			     GTK_SIGNAL_FUNC (gtk_object_destroy), 
+			     GTK_OBJECT (view));
+
   return vbox;
 }
 
@@ -329,6 +350,8 @@ mdi_color_generic_post_change (MDIColorGeneric *mcg, MDIColor *col,
                     Ca ne sert  rien de modifier ET de supprimer une couleur 
   */
 
+  mdi_color_generic_set_modified (mcg, TRUE);  
+
   if (type == CHANGE_CLEAR) {
     g_list_free (mcg->changes);
     col = g_new0 (MDIColor, 1);
@@ -417,7 +440,6 @@ mdi_color_generic_append_new (MDIColorGeneric *mcg,
   col->b      = b;
   col->name   = g_strdup (name);
   col->change = 0;
-  col->owner  = mcg;
   col->change_phase = 0;
 
   mdi_color_generic_append (mcg, col);
@@ -444,7 +466,8 @@ mdi_color_generic_append (MDIColorGeneric *mcg, MDIColor *col)
   GList *pos;
 
   mcg->last++;
-
+  col->owner = mcg;
+  
   if (! mcg->col) { /* Empty */
     col->list = mcg->col = mcg->last_col = g_list_append (NULL, col);
     col->pos = 0;
@@ -609,7 +632,7 @@ mdi_color_generic_change_pos (MDIColorGeneric *mcg,
 
   if (new_pos < col->pos) {
     list = mdi_color_generic_find_col (mcg, new_pos);
-    for (i = new_pos; i < col->pos; i++, list = g_list_next (list)) {
+    for (i = new_pos; i < col->pos && list; i++, list = g_list_next (list)) {
       col_tmp = list->data;
       col_tmp->pos++;
       mdi_color_generic_post_change (mcg, col_tmp, CHANGE_POS);
@@ -619,7 +642,7 @@ mdi_color_generic_change_pos (MDIColorGeneric *mcg,
 
     if (new_pos > col->pos) {     
       list = mdi_color_generic_find_col (mcg, new_pos);
-      for (i = new_pos; i > col->pos; i--, list = g_list_previous (list)) {
+      for (i = new_pos; i > col->pos && list; i--, list = g_list_previous (list)){
 	col_tmp = list->data;
 	col_tmp->pos--;
 	mdi_color_generic_post_change (mcg, col_tmp, CHANGE_POS);
@@ -677,13 +700,42 @@ void mdi_color_generic_disconnect (MDIColorGeneric *mcg,
 {
   mcg->other_views = g_list_remove (mcg->other_views, to);
   to->parents = g_list_remove (to->parents, mcg);
+}
 
-  /* send remove request for 'mcg color' to disconnected document 'to' */
+static void 
+mdi_color_generic_clear_all_other_views (MDIColorGeneric *mcg)
+{
+  GList *list = mcg->other_views;
+  gboolean done = FALSE;
+  MDIColorGeneric *to;
 
-  mdi_color_generic_set_all_color_change (mcg, CHANGE_REMOVE);
-  gtk_signal_emit_by_name (GTK_OBJECT (to), "document_changed", mcg->col);
-//  mdi_color_generic_set_all_color_change (mcg, 0);
-  mcg->changes_phase++;
+  while (list) {
+    to = list->data;
+
+    if (g_list_length (to->parents) == 1) {
+      MDIColor tmp;
+      GList list;
+      
+      tmp.change = CHANGE_CLEAR;
+      tmp.owner = mcg;
+      
+      list.data = &tmp;
+      list.next = list.prev = NULL;
+      
+      gtk_signal_emit_by_name (GTK_OBJECT (to), "document_changed", &list);
+    } else {
+      if (!done) {
+	mdi_color_generic_set_all_color_change (mcg, CHANGE_REMOVE);
+	done = TRUE;
+      }
+      gtk_signal_emit_by_name (GTK_OBJECT (to), "document_changed", mcg->col);
+    }
+
+    list = g_list_next (list);
+  }
+  
+  if (done)
+    mcg->changes_phase++;
 }
 
 MDIColor *
@@ -736,6 +788,43 @@ mdi_color_generic_append_view_type (MDIColorGeneric *mcg, GtkType type)
   mcg->views_type = g_list_append (mcg->views_type, GINT_TO_POINTER (type));
 }
 
+void
+mdi_color_generic_set_modified (MDIColorGeneric *mcg, gboolean modified)
+{  
+  if ((mcg->monitor_modified)&&(mcg->modified != modified)) {    
+    char *tmp = g_strdup (mcg->name); /* Because of g_free in set_name ! */
+    mcg->modified = modified;
+    mdi_color_generic_set_name (mcg, tmp);      
+    g_free (tmp);
+  } else
+    mcg->modified = modified;
+}
+
+void 
+mdi_color_generic_set_name (MDIColorGeneric *mcg, char *name)
+{
+  if (mcg->name) 
+    g_free (mcg->name);
+
+  if (name)
+    mcg->name = g_strdup (name);
+  else
+    mcg->name = g_strdup ("");
+
+  if ((mcg->monitor_modified) && (mcg->modified)) {
+    char *tmp = g_strconcat (mcg->name, "*", NULL);
+    gnome_mdi_child_set_name (GNOME_MDI_CHILD (mcg), tmp); 
+    g_free (tmp);
+  } else 
+    gnome_mdi_child_set_name (GNOME_MDI_CHILD (mcg), mcg->name);
+}
+
+void 
+mdi_color_generic_set_temp (MDIColorGeneric *mcg, gboolean val)
+{
+  mcg->temp = val;
+}
+
 /******************************* PROPERTIES ********************************/
 
 typedef struct prop_t {
@@ -790,11 +879,8 @@ mdi_color_generic_sync (MDIColorGeneric *mcg, gpointer data)
 {
   prop_t *prop = data;
 
-  printf ("MDI :: sync\n");
-
   gtk_signal_handler_block_by_data (GTK_OBJECT (prop->entry_name), prop);
-  gtk_entry_set_text (GTK_ENTRY (prop->entry_name), 
-		      GNOME_MDI_CHILD (mcg)->name);
+  gtk_entry_set_text (GTK_ENTRY (prop->entry_name), mcg->name);
   gtk_signal_handler_unblock_by_data (GTK_OBJECT (prop->entry_name), prop);
 }
 
@@ -803,9 +889,7 @@ mdi_color_generic_apply (MDIColorGeneric *mcg, gpointer data)
 {
   prop_t *prop = data;  
 
-  printf ("MDI :: apply\n");
-
-  gnome_mdi_child_set_name (GNOME_MDI_CHILD (mcg), 
+  mdi_color_generic_set_name (mcg, 
 			    gtk_entry_get_text (GTK_ENTRY (prop->entry_name)));
 }
 
@@ -814,8 +898,6 @@ mdi_color_generic_close (MDIColorGeneric *mcg, gpointer data)
 {
   prop_t *prop = data;
 
-  printf ("MDI :: close\n");
-
   gtk_object_unref (GTK_OBJECT (prop->gui));
   g_free (prop);
 }
@@ -825,7 +907,8 @@ mdi_color_generic_close (MDIColorGeneric *mcg, gpointer data)
 static void
 mdi_color_generic_save (MDIColorGeneric *mcg)
 {
-  gnome_config_set_string ("Name", GNOME_MDI_CHILD (mcg)->name);
+  gnome_config_set_string ("Name", mcg->name);
+  gnome_config_set_bool ("Temp", mcg->temp);
 }
 
 static void
@@ -833,7 +916,8 @@ mdi_color_generic_load (MDIColorGeneric *mcg)
 {
   char *str = gnome_config_get_string ("Name");
 
-  gnome_mdi_child_set_name (GNOME_MDI_CHILD (mcg), str);
+  mdi_color_generic_set_name (mcg, str);
+  mcg->temp = gnome_config_get_bool ("Temp");
 
   g_free (str);
 }
