@@ -2,11 +2,15 @@
 #include <gnome.h>
 #include <glade/glade.h>
 
+#include <gdk/gdkx.h>
+
 #include "view-color-generic.h"
 #include "view-color-list.h"
 #include "mdi-color-generic.h"
 #include "menus.h"
 #include "utils.h"
+#include "idle.h"
+#include "gcolorsel.h"
 
 static ViewColorGenericClass *parent_class = NULL;
 
@@ -68,8 +72,8 @@ view_color_list_compare_rows    (GtkCList *clist,
 static void
 view_color_list_data_changed    (ViewColorGeneric *vcg, gpointer data);
 
-static void
-view_color_list_remove_selected (ViewColorGeneric *vcg);
+static GList *view_color_list_get_selected (ViewColorGeneric *vcg);
+static int    view_color_list_get_insert_pos  (ViewColorGeneric *vcg);
 static gpointer 
 view_color_list_get_control     (ViewColorGeneric *vcg, GtkVBox *box,
 				 void (*changed_cb)(gpointer data), 
@@ -132,7 +136,8 @@ view_color_list_class_init (ViewColorListClass *class)
   vcg_class    = (ViewColorGenericClass *)class;
 
   vcg_class->data_changed    = view_color_list_data_changed;
-  vcg_class->remove_selected = view_color_list_remove_selected;
+  vcg_class->get_selected    = view_color_list_get_selected;
+  vcg_class->get_insert_pos  = view_color_list_get_insert_pos;
   vcg_class->get_control     = view_color_list_get_control;
   vcg_class->close           = view_color_list_close;
   vcg_class->apply           = view_color_list_apply;
@@ -227,13 +232,13 @@ view_color_list_destroy (GtkObject *object)
     g_list_free (vcl->idle_todo);
 
   if (vcl->idle)
-    gtk_idle_remove (vcl->idle);
+    idle_remove (vcl->idle);
+
+  if (vcl->gc)
+    gdk_gc_unref (vcl->gc);
+  if (vcl->pixmap_font)
+    gdk_font_unref (vcl->pixmap_font);
 
-  gdk_gc_unref (vcl->gc);
-  gdk_color_free (&vcl->color_black);
-  gdk_color_free (&vcl->color_white);
-  gdk_font_unref (vcl->pixmap_font);
-  
   if (GTK_OBJECT_CLASS (parent_class)->destroy)
     GTK_OBJECT_CLASS (parent_class)->destroy (object);
 }
@@ -376,25 +381,35 @@ view_color_list_button_press (GtkCList *clist, GdkEventButton *event,
   int col, row;
   GtkCListRow *r;
 
-  if (event->button == 3) {
-    if (gtk_clist_get_selection_info (clist, event->x, event->y, &row, &col));
+  if (event->type == GDK_BUTTON_PRESS) {
+
+    if (event->button == 3) {
+      if (gtk_clist_get_selection_info (clist, event->x, event->y, &row, &col)){
+	
+	/* 1. Si la ligne est deja selectionnee, on continue 
+	   2. Sinon, on deselectionne tout et on selectionne la ligne */
+	
+	r = g_list_nth (clist->row_list, row)->data;
+	if (r->state != GTK_STATE_SELECTED) {
+	  gtk_clist_freeze (clist);
+	  gtk_clist_unselect_all (clist);
+	  clist->focus_row = row;
+	  gtk_clist_select_row (clist, row, col);
+	  gtk_clist_thaw (clist);
+	}      
+	
+	menu_view_do_popup (event);
+	return FALSE;
+      }
+    }
     
-    /* 1. Si la ligne est deja selectionnee, on continue 
-       2. Sinon, on deselectionne tout et on selectionne la ligne */
-    
-    r = g_list_nth (clist->row_list, row)->data;
-    if (r->state != GTK_STATE_SELECTED) {
-      gtk_clist_freeze (clist);
-      gtk_clist_unselect_all (clist);
-      clist->focus_row = row;
-      gtk_clist_select_row (clist, row, col);
-      gtk_clist_thaw (clist);
-    }      
+  } else
+      
+      if (event->type == GDK_2BUTTON_PRESS) {
+	if(gtk_clist_get_selection_info(clist, event->x, event->y, &row, &col))
+	  actions_views (gtk_clist_get_row_data (clist, row));
+      }
 
-    menu_view_do_popup (event);
-    return FALSE;
-  }
-  
   return TRUE;
 }
 
@@ -476,29 +491,39 @@ view_color_list_idle (gpointer data)
   GdkPixmap *pixmap;  
   int row;
   GtkCList *clist = GTK_CLIST (VIEW_COLOR_GENERIC (vcl)->widget);
+  int i;
 
-  if (! vcl->idle_todo) {
-    vcl->idle = 0;
-    return FALSE;
+  for (i = 0; i < 10; i++) {
+
+    if (! vcl->idle_todo) {
+      vcl->idle = 0;
+      return FALSE;
+    }
+    
+    col = vcl->idle_todo->data;
+    vcl->idle_todo = g_list_remove (vcl->idle_todo, col);
+    
+    row = gtk_clist_find_row_from_data (clist, col);
+    
+    if (VIEW_COLOR_GENERIC (vcl)->widget->window)
+      pixmap = gdk_pixmap_new (VIEW_COLOR_GENERIC (vcl)->widget->window, 
+			       vcl->col_width,
+			       vcl->col_height, 
+			       -1);
+    else
+      pixmap = gdk_pixmap_new (GDK_ROOT_PARENT (),
+			       vcl->col_width,
+			       vcl->col_height,
+			       -1);
+    
+    view_color_list_render_pixmap (vcl, pixmap, col);
+    
+    gtk_clist_set_pixmap (clist, row, 
+			  COLUMN_PIXMAP, pixmap, NULL);
+    
+    gdk_pixmap_unref (pixmap);
   }
   
-  col = vcl->idle_todo->data;
-  vcl->idle_todo = g_list_remove (vcl->idle_todo, col);
-  
-  row = gtk_clist_find_row_from_data (clist, col);
-  
-  pixmap = gdk_pixmap_new (VIEW_COLOR_GENERIC (vcl)->widget->window, 
-			   vcl->col_width,
-			   vcl->col_height, 
-			   -1);
-
-  view_color_list_render_pixmap (vcl, pixmap, col);
-
-  gtk_clist_set_pixmap (clist, row, 
-			COLUMN_PIXMAP, pixmap, NULL);
-
-  gdk_pixmap_unref (pixmap);
-  
   return TRUE;
 }
 
@@ -508,7 +533,7 @@ view_color_list_idle_append (ViewColorList *vcl, MDIColor *col)
   vcl->idle_todo = g_list_prepend (vcl->idle_todo, col);
   
   if (! vcl->idle) 
-    vcl->idle = gtk_idle_add (view_color_list_idle, vcl); 
+    vcl->idle = idle_add (view_color_list_idle, vcl); 
 }
 
 static gint
@@ -548,8 +573,12 @@ view_color_list_render_pixmap (ViewColorList *vcl, GdkPixmap *pixmap,
   
   gdk_color_alloc (gtk_widget_get_default_colormap (), &color);
 
-  if (vcl->gc == NULL) 
-    vcl->gc = gdk_gc_new (VIEW_COLOR_GENERIC (vcl)->widget->window);
+  if (vcl->gc == NULL) {
+    if (VIEW_COLOR_GENERIC (vcl)->widget->window)
+      vcl->gc = gdk_gc_new (VIEW_COLOR_GENERIC (vcl)->widget->window);
+    else
+      vcl->gc = gdk_gc_new (GDK_ROOT_PARENT ());
+  }
 
   /* Border */
   gdk_gc_set_foreground (vcl->gc, &vcl->color_black);
@@ -670,33 +699,31 @@ view_color_list_data_changed (ViewColorGeneric *vcg, gpointer data)
 
 }
 
-static void
-view_color_list_remove_selected (ViewColorGeneric *vcg)
+static gint
+view_color_list_get_insert_pos (ViewColorGeneric *vcg)
+{
+  GtkCList *clist = GTK_CLIST (vcg->widget);
+
+  return clist->focus_row;
+}
+
+static GList *
+view_color_list_get_selected (ViewColorGeneric *vcg)
 {
   GtkCList *clist = GTK_CLIST (vcg->widget);
   GList *list = clist->selection;
   MDIColor *col;
-  GList *freezed = NULL;
+  GList *get_list = NULL;
 
   while (list) {
     col = gtk_clist_get_row_data (clist, GPOINTER_TO_INT (list->data));   
+    
+    get_list = g_list_prepend (get_list, col);
+
     list = g_list_next (list);
-    
-    col = mdi_color_generic_get_owner (col);
-    
-    mdi_color_generic_freeze (col->owner);
-    mdi_color_generic_remove (col->owner, col);
-    
-    freezed = g_list_prepend (freezed, col->owner);
   }   
 
-  list = freezed;
-  while (list) {
-    mdi_color_generic_thaw (freezed->data);
-    list = g_list_next (list);
-  }    
-
-  g_list_free (freezed);
+  return get_list;
 }
 
 /*************************** PROPERTIES **********************************/
@@ -771,8 +798,6 @@ view_color_list_apply (ViewColorGeneric *vcg, gpointer data)
   prop_t *prop = data;
   GtkCList *clist = GTK_CLIST (vcg->widget);
 
-  printf ("List    :: apply\n");
-
   VIEW_COLOR_LIST (vcg)->col_width = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (prop->spin_width));
   
   VIEW_COLOR_LIST (vcg)->col_height = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (prop->spin_height));
@@ -791,8 +816,6 @@ view_color_list_close (ViewColorGeneric *vcg, gpointer data)
 {
   prop_t *prop = data;
 
-  printf ("List    :: close\n");
-
   parent_class->close (vcg, prop->parent_data);
 
   gtk_object_unref (GTK_OBJECT (prop->gui));
@@ -805,8 +828,6 @@ view_color_list_sync (ViewColorGeneric *vcg, gpointer data)
   prop_t *prop = data;
   ViewColorList *vcl = VIEW_COLOR_LIST (vcg);
 
-  printf ("List    :: sync \n");
-
   spin_set_value (GTK_SPIN_BUTTON (prop->spin_width), vcl->col_width, prop);
   spin_set_value (GTK_SPIN_BUTTON (prop->spin_height), vcl->col_height, prop);
 
@@ -835,6 +856,9 @@ view_color_list_save (ViewColorGeneric *vcg)
   gnome_config_set_bool ("SortAscending", 
 			 clist->sort_type == GTK_SORT_ASCENDING);
 
+  gnome_config_set_int ("ColumnValueWidth", 
+			clist->column[COLUMN_VALUE].width);
+
   parent_class->save (vcg);
 }
 
@@ -844,8 +868,8 @@ view_color_list_load (ViewColorGeneric *vcg)
   ViewColorList *vcl = VIEW_COLOR_LIST (vcg);
   GtkCList *clist = GTK_CLIST (VIEW_COLOR_GENERIC (vcl)->widget);
 
-  vcl->col_width    = gnome_config_get_int ("ColWidth");
-  vcl->col_height   = gnome_config_get_int ("ColHeight");
+  vcl->col_width    = gnome_config_get_int ("ColWidth=48");
+  vcl->col_height   = gnome_config_get_int ("ColHeight=15");
   vcl->draw_numbers = gnome_config_get_bool ("DrawNumbers");
 
   view_color_list_set_sort_column (vcl, 
@@ -857,5 +881,8 @@ view_color_list_load (ViewColorGeneric *vcg)
   gtk_clist_set_row_height (clist, vcl->col_height);
   gtk_clist_set_column_width (clist, COLUMN_PIXMAP, vcl->col_width);
 
+  gtk_clist_set_column_width (clist, COLUMN_VALUE, 
+			      gnome_config_get_int ("ColumnValueWidth=50"));
+
   parent_class->load (vcg);
 }
