@@ -22,6 +22,7 @@
 
 #include <config.h>
 #include <gnome.h>
+#include <libgnomeui/gnome-window-icon.h>
 #include <errno.h>
 
 #include <sys/utsname.h>
@@ -136,6 +137,8 @@ main ( int argc, char ** argv )
   gnome_init (APPNAME, VERSION, argc, argv);
 #endif /* ! GUNAME_CAPPLET */
 
+  gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-info.png");
+
   load_system_info ();
 
 #if HAVE_LIBGTOP
@@ -418,6 +421,21 @@ free_imlib_image (GtkObject *object, gpointer data)
 
 #endif
 
+static void
+close_cb (GtkWidget * widget, gpointer user_data)
+{
+        gtk_widget_destroy (widget);
+        gtk_main_quit ();
+}
+
+static void
+help_cb (GtkWidget * widget, gpointer user_data)
+{
+    GnomeHelpMenuEntry ref = {"guname", "index.html"};
+                        gnome_help_display (NULL, &ref);
+}
+
+
 static void popup_main_dialog()
 {
   GtkWidget * d;
@@ -425,9 +443,9 @@ static void popup_main_dialog()
   GtkWidget * list_box;
 
   d = gnome_dialog_new( _("System Information"), 
-                        GNOME_STOCK_BUTTON_OK, NULL );
-
-  gnome_dialog_set_close(GNOME_DIALOG(d), TRUE);
+                        GNOME_STOCK_BUTTON_OK,
+                        GNOME_STOCK_BUTTON_HELP, 
+                        NULL );
  
   logo_box = gtk_vbox_new(FALSE, GNOME_PAD_SMALL/2);
   do_logo_box(logo_box);
@@ -440,9 +458,14 @@ static void popup_main_dialog()
   gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(d)->vbox), list_box,
                      TRUE, TRUE, GNOME_PAD_SMALL/2);
 
-  gtk_signal_connect(GTK_OBJECT(d), "close",
-                     GTK_SIGNAL_FUNC(gtk_main_quit),
-                     NULL);
+  gtk_signal_connect (GTK_OBJECT(d), "close", 
+                       GTK_SIGNAL_FUNC(close_cb), &d); 
+
+  gnome_dialog_button_connect (GNOME_DIALOG (d), 0,
+                               GTK_SIGNAL_FUNC (close_cb), &d);
+  gnome_dialog_button_connect (GNOME_DIALOG (d), 1,
+                                     GTK_SIGNAL_FUNC (help_cb), &d);
+  gnome_dialog_set_default (GNOME_DIALOG (d), 0);
 
   gtk_widget_show_all(d);
 }
@@ -600,7 +623,7 @@ static void do_list_box(GtkWidget * box)
   
   gtk_clist_freeze(list); /* does this matter if we haven't shown yet? */
 
-  gtk_clist_set_shadow_type(list, GTK_SHADOW_OUT);
+  gtk_clist_set_shadow_type(list, GTK_SHADOW_IN);
   /* Fixme, eventually you might could select an item 
      for cut and paste, or some other effect. */
   gtk_clist_set_selection_mode(list, GTK_SELECTION_BROWSE);
@@ -719,7 +742,7 @@ static void save_callback(GtkWidget * menuitem, gpointer data)
   }
 
   fs = gtk_file_selection_new(_("Save System Information As..."));
-  
+  gnome_window_icon_set_from_default (GTK_WINDOW (fs));
   gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(fs)->ok_button), "clicked",
                      GTK_SIGNAL_FUNC(file_selection_cb), fs);
 
